@@ -40,11 +40,11 @@ cor_lower.easycorrelation <- function(x, diag = FALSE, ...) {
   rownames(tri) <- rownames(m)
   colnames(tri) <- colnames(m)
 
-  tokeep <- c()
+  tokeep <- NULL
 
   for (param1 in rownames(m)) {
     for (param2 in colnames(m)) {
-      if (tri[param1, param2] == TRUE) {
+      if (tri[param1, param2]) {
         tokeep <- c(tokeep, which(x$Parameter1 == param1 & x$Parameter2 == param2))
       }
     }
