@@ -148,6 +148,13 @@ cor_test <- function(data,
     data[c(x, y)] <- datawizard::to_numeric(data[c(x, y)], dummy_factors = FALSE)
   }
 
+  # However, for poly, we need factors!
+  if (method %in% c("poly", "polychoric") && all(vapply(data[c(x, y)], is.numeric, FUN.VALUE = TRUE))) {
+    # convert all input to factors, but only if all input currently is numeric
+    # we allow mix of numeric and factors
+    data[c(x, y)] <- datawizard::to_factor(data[c(x, y)])
+  }
+
   # Partial
   if (!isFALSE(partial)) {
     # partial
@@ -300,13 +307,9 @@ cor_test <- function(data,
 }
 
 
-
-
-
 # Utilities ---------------------------------------------------------------
 
 
-
 #' @keywords internal
 .complete_variable_x <- function(data, x, y) {
   data[[x]][stats::complete.cases(data[[x]], data[[y]])]
